==> google_cloud_tasks-2.8.1-py2.py3-none-any.whl: google/cloud/tasks_v2beta2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudtasks import (
    AcknowledgeTaskRequest,
    CancelLeaseRequest,
    CreateQueueRequest,
    CreateTaskRequest,
    DeleteQueueRequest,
    DeleteTaskRequest,
    GetQueueRequest,
    GetTaskRequest,
    LeaseTasksRequest,
    LeaseTasksResponse,
    ListQueuesRequest,
    ListQueuesResponse,
    ListTasksRequest,
    ListTasksResponse,
    PauseQueueRequest,
    PurgeQueueRequest,
    RenewLeaseRequest,
    ResumeQueueRequest,
    RunTaskRequest,
    UpdateQueueRequest,
)
from .queue import (
    Queue,
    QueueStats,
    RateLimits,
    RetryConfig,
)
from .target import (
    AppEngineHttpRequest,
    AppEngineHttpTarget,
    AppEngineRouting,
    PullMessage,
    PullTarget,
    HttpMethod,
)
from .task import (
    AttemptStatus,
    Task,
    TaskStatus,
)

__all__ = (
    "AcknowledgeTaskRequest",
    "CancelLeaseRequest",
    "CreateQueueRequest",
    "CreateTaskRequest",
    "DeleteQueueRequest",
    "DeleteTaskRequest",
    "GetQueueRequest",
    "GetTaskRequest",
    "LeaseTasksRequest",
    "LeaseTasksResponse",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "PauseQueueRequest",
    "PurgeQueueRequest",
    "RenewLeaseRequest",
    "ResumeQueueRequest",
    "RunTaskRequest",
    "UpdateQueueRequest",
    "Queue",
    "QueueStats",
    "RateLimits",
    "RetryConfig",
    "AppEngineHttpRequest",
    "AppEngineHttpTarget",
    "AppEngineRouting",
    "PullMessage",
    "PullTarget",
    "HttpMethod",
    "AttemptStatus",
    "Task",
    "TaskStatus",
)

==> google_cloud_tasks-2.15.0-py2.py3-none-any.whl: google/cloud/tasks_v2beta2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudtasks import (
    AcknowledgeTaskRequest,
    BufferTaskRequest,
    BufferTaskResponse,
    CancelLeaseRequest,
    CreateQueueRequest,
    CreateTaskRequest,
    DeleteQueueRequest,
    DeleteTaskRequest,
    GetQueueRequest,
    GetTaskRequest,
    LeaseTasksRequest,
    LeaseTasksResponse,
    ListQueuesRequest,
    ListQueuesResponse,
    ListTasksRequest,
    ListTasksResponse,
    PauseQueueRequest,
    PurgeQueueRequest,
    RenewLeaseRequest,
    ResumeQueueRequest,
    RunTaskRequest,
    UpdateQueueRequest,
    UploadQueueYamlRequest,
)
from .queue import Queue, QueueStats, RateLimits, RetryConfig
from .target import (
    AppEngineHttpRequest,
    AppEngineHttpTarget,
    AppEngineRouting,
    HttpMethod,
    HttpRequest,
    HttpTarget,
    OAuthToken,
    OidcToken,
    PathOverride,
    PullMessage,
    PullTarget,
    QueryOverride,
    UriOverride,
)
from .task import AttemptStatus, Task, TaskStatus

__all__ = (
    "AcknowledgeTaskRequest",
    "BufferTaskRequest",
    "BufferTaskResponse",
    "CancelLeaseRequest",
    "CreateQueueRequest",
    "CreateTaskRequest",
    "DeleteQueueRequest",
    "DeleteTaskRequest",
    "GetQueueRequest",
    "GetTaskRequest",
    "LeaseTasksRequest",
    "LeaseTasksResponse",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "PauseQueueRequest",
    "PurgeQueueRequest",
    "RenewLeaseRequest",
    "ResumeQueueRequest",
    "RunTaskRequest",
    "UpdateQueueRequest",
    "UploadQueueYamlRequest",
    "Queue",
    "QueueStats",
    "RateLimits",
    "RetryConfig",
    "AppEngineHttpRequest",
    "AppEngineHttpTarget",
    "AppEngineRouting",
    "HttpRequest",
    "HttpTarget",
    "OAuthToken",
    "OidcToken",
    "PathOverride",
    "PullMessage",
    "PullTarget",
    "QueryOverride",
    "UriOverride",
    "HttpMethod",
    "AttemptStatus",
    "Task",
    "TaskStatus",
)
